package com.brie;

import java.io.Serializable;
import java.util.Date;

import javax.annotation.Resource;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;
import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.Future;
import javax.validation.constraints.Min;
import javax.validation.constraints.Max;
import javax.validation.constraints.Size;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.PersistenceUnit;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.UserTransaction;


import org.hibernate.validator.constraints.Email;

@Named
@SessionScoped
public class PartyRequest implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	
	   @PersistenceUnit
	   private EntityManagerFactory emf;

	   @Resource
	   private UserTransaction utx;
	
	@Future
	private Date partydate;
	
	private Date endDate;
	

	@Size(min=2, max=100)
	private String name;
	
	@DecimalMin(value = "3.0")
	@DecimalMax(value = "11.0")
	private Double duration;
	
	@Email
	private String email;
	
	public Date getPartydate() {
		return partydate;
	}


	public void setPartydate(Date partydate) {
		this.partydate = partydate;
	}


	public String getName() {
		return name;
	}


	public void setName(String name) {
		this.name = name;
	}


	public Double getDuration() {
		return duration;
	}


	public void setDuration(Double duration) {
		this.duration = duration;
	}


	public String getEmail() {
		return email;
	}


	public void setEmail(String email) {
		this.email = email;
	}


	public String summary() {
		if (partydate != null && name.length() >= 2 && duration >= 2.0 && email.length() > 2) {
			return "summary";
			
		} 
		return "index";
	}
	
	public String commit() throws NotSupportedException, SystemException, SecurityException, IllegalStateException, RollbackException, HeuristicMixedException, HeuristicRollbackException {
		EntityManager em = emf.createEntityManager();
		try {
			utx.begin();
			em.joinTransaction();
			boolean committed = false;
			try {
				Party myParty = new Party();
				myParty.setDuration(duration);
				myParty.setEmail(email);
				myParty.setName(name);
				myParty.setPartydate(partydate);
				em.persist(myParty);
				utx.commit();
				
				committed = true;
				duration = null;
				email = null;
				name = null;
				partydate = null;
			} finally {
				if (!committed) utx.rollback();
			}
			
		} finally {
			em.close();
		}
		return "thankyou";
	}

	

	public PartyRequest() {
//		partydate =  new Date();
//		name = new String("");
//		duration = 0.0;
//		email = "";
	}


	public Date getEndDate() {
		Long time = partydate.getTime();
		time += (long) (duration*60*60*1000);
		endDate = new Date(time);
		return endDate;
	}




}
